<?php
namespace Ak\Form\Annotation;

use Interop\Container\ContainerInterface;
use Laminas\Form\FormInterface;
use Laminas\ServiceManager\Factory\AbstractFactoryInterface;

/**
 * Class AnnotatedFormAbstractFactory
 *
 * @package Ak\Form\Annotation
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/wp-core
 */
final class AnnotatedFormAbstractFactory implements AbstractFactoryInterface
{
    /**
     * Can the factory create an instance for the service?
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @return bool
     */
    public function canCreate(ContainerInterface $container, $requestedName)
    {
        return class_exists($requestedName) && !is_subclass_of($requestedName, 'Laminas\Form\ElementInterface');
    }

    /**
     * Create an object
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return FormInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        /** @var AnnotationBuilder $builder */
        $builder = $container->get('FormAnnotationBuilder');
        return $builder->createForm($requestedName);
    }
}
