<?php
namespace Ak\Form\Element;

use Ak\View\IconAwareInterface;
use Laminas\Form\Element;

/**
 * <button> element.
 *
 * @package Ak\Form\Element
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/form
 */
class Button extends Element implements IconAwareInterface
{
    /**
     * Seed attributes
     *
     * @var array
     */
    protected $attributes = [
        'type' => 'button',
    ];

    /** @var string */
    protected $style;

    /** @var string */
    protected $icon;

    public function __construct($name = null, array $options = [])
    {
        parent::__construct($name, $options);
    }

    /**
     * @param array|\Traversable $options
     * @return $this|Element|\Laminas\Form\ElementInterface
     */
    public function setOptions($options)
    {
        parent::setOptions($options);

        if (isset($options['icon'])) {
            $this->setIcon($options['icon']);
        }

        if (isset($options['style'])) {
            $this->setStyle($options['style']);
        }

        return $this;
    }

    /**
     * @return string
     */
    public function getIcon(): string
    {
        return (string) $this->icon;
    }

    /**
     * @param string $icon
     */
    public function setIcon(string $icon): void
    {
        $this->icon = (string) $icon;
    }

    /**
     * @return string
     */
    public function getStyle(): string
    {
        return $this->style;
    }

    /**
     * @param string $style
     */
    public function setStyle(string $style): void
    {
        $this->style = $style;
    }
}
