<?php
namespace Ak\Form\Element;

use Ak\Form\ElementInterface;
use Ak\Form\ElementTrait;
use Laminas\Form\Element\Checkbox as BaseCheckbox;

/**
 * Predstavlja checkbox element.
 *
 * @package Ak\Form\Element
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/form
 */
class Checkbox extends BaseCheckbox implements ElementInterface
{
    use ElementTrait {
        setOptions as _setOptions;
    }

    /** @var ?string */
    private $uncheckWarning;

    /**
     * Postavlja postavke elementa.
     *
     * @param array|\Traversable $options
     * @return ElementInterface
     */
    public function setOptions($options)
    {
        if (isset($options['uncheck_warning'])) {
            $this->setUncheckWarning($options['uncheck_warning']);
        }

        return $this->_setOptions($options);
    }

    /**
     * Vraća upozorenje kad se checkbox odznači.
     *
     * @return null|string
     */
    public function getUncheckWarning(): ?string
    {
        return $this->uncheckWarning;
    }

    /**
     * Postavlja upozorenje kad se checkbox odznači.
     *
     * @param string $uncheckWarning
     */
    public function setUncheckWarning(string $uncheckWarning): void
    {
        $this->uncheckWarning = $uncheckWarning;
    }
}
