<?php
namespace Ak\Form\View\Helper;

use Ak\Form\Element\Checkbox;
use Laminas\Form\ElementInterface;
use Laminas\Form\Element\Checkbox as CheckboxElement;

/**
 * Renderira <input type="checkbox"> element.
 *
 * @package Ak\Form\View\Helper
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/form
 */
final class FormCheckbox extends FormInput
{
    use HelperTools;

    /** @var FormLabel */
    private $formLabelHelper;

    /**
     * Vraća FormLabel helper.
     *
     * @return FormLabel
     */
    private function getFormLabelHelper()
    {
        if (null === $this->formLabelHelper) {
            if (method_exists($this->view, 'plugin')) {
                $this->formLabelHelper = $this->view->plugin('form_label');
            } else {
                $this->formLabelHelper = new FormLabel();
            }
        }

        return $this->formLabelHelper;
    }

    /**
     * Renderira element.
     *
     * @param ElementInterface $element
     *
     * @return string
     */
    public function render(ElementInterface $element): string
    {
        if (! $element instanceof CheckboxElement) {
            throw new \InvalidArgumentException(sprintf(
                '%s requires that the element is of type Laminas\Form\Element\Checkbox',
                __METHOD__
            ));
        }

        if ($labelText = $element->getLabel()) {
            $labelAttributes = $element->getLabelAttributes();
            $labelAttributes['class'] = trim('Checkbox__Label ' . ($labelAttributes['class'] ?? ''));
            $element->setLabelAttributes($labelAttributes);

            $formLabelHelper = $this->getFormLabelHelper();
            $label = $formLabelHelper($element);
        }

        $this->addCssClass($element, ['Checkbox__Input']);
        $this->removeCssClass($element, 'FormControl__Input');

        $elementAttributes = $element->getAttributes();
        $elementAttributes['name'] = $element->getName();
        $elementAttributes['value'] = $element->getCheckedValue();

        if ($element->isChecked()) {
            $elementAttributes['checked'] = 'checked';
        }

        /** @noinspection HtmlUnknownAttribute */
        $input = sprintf('<input type="checkbox" %s>', $this->createAttributesString($elementAttributes));

        if ($element->useHiddenElement()) {
            $hiddenAttributes = [
                'disabled' => isset($attributes['disabled']) ? $elementAttributes['disabled'] : false,
                'name'     => $elementAttributes['name'],
                'value'    => $element->getUncheckedValue(),
            ];

            /** @noinspection HtmlUnknownAttribute */
            $hidden = sprintf('<input type="hidden" %s>', $this->createAttributesString($hiddenAttributes));
        }

        $attributes = [
            'class' => 'Checkbox FormControl__Input',
        ];

        if ($element instanceof Checkbox && ($uncheckWarning = $element->getUncheckWarning())) {
            $attributes['data-uncheck-warning'] = $uncheckWarning;
        }

        /** @noinspection HtmlUnknownAttribute */
        return sprintf('<div %s>%s%s%s</div>', $this->createAttributesString($attributes), $hidden ?? '', $input, $label ?? '');
    }
}
