<?php
namespace Ak\Form\View\Helper;

use Ak\Form\Element\Button;
use Laminas\Form\Element\Hidden;
use Laminas\Form\ElementInterface;
use Laminas\Form\View\Helper\AbstractHelper;

/**
 * Renderira kompletni element obrasca.
 *
 * @package Ak\Form\View\Helper
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/form
 */
class FormElement extends AbstractHelper
{
	/** @var FormLabel */
	protected $formLabel;
	/** @var FormControl */
	protected $formControl;
	/** @var FormElementDescription */
	protected $formElementDescription;

	/**
	 * Vraća FormLabel helper.
	 *
	 * @return FormLabel
	 */
	protected function getFormLabelHelper()
	{
		if (null === $this->formLabel) {
			$this->formLabel = method_exists($this->view, 'plugin')
				? $this->view->plugin('form_label')
				: new FormLabel();
		}

		return $this->formLabel;
	}

	/**
	 * Vraća FormControl helper.
	 *
	 * @return FormControl
	 */
	protected function getFormControlHelper()
	{
		if (null === $this->formControl) {
			$this->formControl = method_exists($this->view, 'plugin')
				? $this->view->plugin('form_control')
				: new FormControl();
		}

		return $this->formControl;
	}

    /**
     * @param ElementInterface|null $element
     *
     * @return FormElement|string
     */
    public function __invoke(ElementInterface $element = null)
    {
        return $element ? $this->render($element) : $this;
    }

    /**
	 * Renderira grupu.
	 *
	 * @param ElementInterface $element    Element čiju grupu renderiramo.
	 *
	 * @return string
	 */
	public function render(ElementInterface $element)
	{
		$formLabel = $this->getFormLabelHelper();
		$formControl = $this->getFormControlHelper();

		$classes = ['FormElement'];

		if ($group_class = $element->getOption('group_class')) {
		    $classes[] = is_array($group_class) ? implode(' ', $group_class) : $group_class;
        }

        $element_class = explode('\\', get_class($element));
        $classes[] = sprintf('FormElement_type_%s', ucfirst(end($element_class)));

        // Label rendamo prije kontrole zato što FormLabel dodaje id elementu koji ga nema,
        // pa se to mora desiti prije nego što rendamo kontrolu.
		if ($element->getLabel()
		    && !$element instanceof Button
		    && !$element instanceof Hidden
		) {
			$label = $formLabel($element);
		} else {
			$label = '';
		}

		$control = $formControl->render($element);

		if ($element instanceof Hidden || $element instanceof Button) {
			return $control;
		}

		$control = $label . "\n" . $control;

		return sprintf('<div class="%s">%s</div>', implode(' ', $classes), $control);
	}
}
