<?php
namespace AkTest\Form\View\Helper;

use Ak\Form\Element\Checkbox;
use Ak\Form\View\Helper\FormCheckbox;
use AkTest\Form\AbstractTestCase;
use AkTest\Form\Mock\HelperInterface;
use Laminas\Form\Element\Text;
use Laminas\Form\ElementInterface;

/**
 * Class FormCheckboxTest
 *
 * @package AkTest\Form\View\Helper
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/form
 */
class CheckboxTest extends AbstractTestCase
{
    public function testIsRegistered()
    {
        $plugins = $this->getHelperPluginManager();

        $this->assertContainerHasService($plugins, [
            'form_checkbox',
            FormCheckbox::class,
        ], FormCheckbox::class, true);
    }

    public function testWillUseFormLabelFromManager()
    {
        $helper = $this->createMock(HelperInterface::class);
        $helper->expects($this->once())
            ->method('__invoke')
            ->with($this->isInstanceOf(ElementInterface::class))
            ->willReturn('');

        $plugins = $this->getHelperPluginManager();
        $plugins->setService('form_label', $helper);

        $helper = $plugins->get('form_checkbox');
        $element = new Checkbox('name');
        $element->setLabel('label');

        $helper($element);
    }

    public function testElementIsRendered()
    {
        $helper = new FormCheckbox();

        $element = new Checkbox('checkbox');
        $element->setLabel('label');

        $rendered = $helper($element);

        $this->assertSelectCount('div.Checkbox', 1, $rendered);
        $this->assertSelectCount('div.Checkbox > input[type="hidden"][name="checkbox"][value="0"]:first-child', 1, $rendered);
        $this->assertSelectCount('div.Checkbox > input.Checkbox__Input[type="checkbox"][name="checkbox"]:nth-child(2)', 1, $rendered);
        $this->assertSelectCount('div.Checkbox > label.Checkbox__Label:last-child', 1, $rendered);
    }

    public function testElementCanBeRenderedWithoutTheLabel()
    {
        $helper = $this->getHelper('form_checkbox');

        $element = new Checkbox('checkbox');

        $helper($element);

        $this->assertTrue(true);
    }

    /**
     * @expectedException \InvalidArgumentException
     */
    public function testHelperWillRenderOnlyCheckboxElements()
    {
        $helper = $this->getHelper('form_checkbox');

        $element = new Text('text');

        $helper($element);
    }

    public function testValueAttributeIsRendered()
    {
        $helper = $this->getHelper('form_checkbox');

        $element = new Checkbox('checkbox', [
            'checked_value' => 'some-value',
        ]);

        $rendered = $helper($element);

        $this->assertSelectCount('input.Checkbox__Input[value="some-value"]', 1, $rendered);
    }

    public function testCheckedAttributeIsRendered()
    {
        $helper = $this->getHelper('form_checkbox');

        $element = new Checkbox('checkbox', [
            'checked_value' => 'some-value',
        ]);
        $element->setValue('some-value');

        $rendered = $helper($element);

        $this->assertSelectCount('input[name="checkbox"][checked]', 1, $rendered);
    }

    public function testUncheckWarningIsRendered()
    {
        $element = new Checkbox('checkbox', [
            'uncheck_warning' => 'thisisit',
        ]);

        $helper = $this->getHelper('form_checkbox');
        $rendered = $helper($element);

        $this->assertSelectCount('.Checkbox[data-uncheck-warning="thisisit"]', 1, $rendered);
    }
}
