<?php
namespace AkTest\Form\View\Helper;

use Ak\Form\Element\Checkbox;
use Ak\Form\View\Helper\HelperTools;
use PHPUnit\Framework\TestCase;
use Laminas\Form\Element\Text;

/**
 * Class HelperToolsTest
 *
 * @package AkTest\Form\View\Helper
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/form
 */
final class HelperToolsTest extends TestCase
{
    use HelperTools;

    public function testAddCssClassWillAddClassesToElement()
    {
        $element = new Text();
        $element->setAttribute('class', 'existing');

        $this->addCssClass($element, 'prepended');
        $this->addCssClass($element, 'appended', 'append');

        $this->assertEquals('prepended existing appended', $element->getAttribute('class'));
    }

    public function testAddCssClassWillNotDuplicateClass()
    {
        $element = new Text();

        $this->addCssClass($element, 'some-class');
        $this->addCssClass($element, 'some-class');

        $this->assertEquals('some-class', $element->getAttribute('class'));
    }

    /**
     * @expectedException \RuntimeException
     */
    public function testAddCssClassWillThrowExceptionForInvalidPosition()
    {
        $element = new Text();

        $this->addCssClass($element, 'class', 'invalid');
    }

    public function testRemoveCssClassRemovesTheClass()
    {
        $element = new Checkbox('checkbox');
        $element->setAttribute('class', 'css-class other-class');

        $this->removeCssClass($element, 'other-class');

        $this->assertEquals('css-class', $element->getAttribute('class'));
    }
}
